﻿using Eto.Forms;
using Eto.Drawing;
using Rhino.UI;
using System;
using System.Collections.Generic;

namespace EtoTreeGridViewDemo1
{
    [System.Runtime.InteropServices.Guid("0E7780CA-F004-4AE7-B918-19E655F7C7B1")]
    public class MainPanel : Panel, IPanel
    {
        public static Guid PanelID => typeof(MainPanel).GUID;
        TreeGridView tree;
        GridColumn column;
        Root root;
        public MainPanel()
        {
            root = new Root();
            column = new GridColumn
            {
                AutoSize = true,
                Editable = true,
                Resizable = false,
                Sortable = false,
                DataCell = new CustomCell
                {
                    CreateCell = (args) => (args.Item as Node).CreateCell(args),
                    ConfigureCell = (args, control) => { control.DataContext = args.Item; }
                }
            };
            tree = new TreeGridView
            {
                ShowHeader = false,
                Size = new Size(-1, -1),
                RowHeight = 25,
                DataStore = root
            };
            tree.Columns.Add(column);
            tree.SizeChanged += (s, e) => column.Width = tree.Width - 25;
            Content = tree;
        }




        public void PanelClosing(uint documentSerialNumber, bool onCloseDocument)
        { }

        public void PanelHidden(uint documentSerialNumber, ShowPanelReason reason)
        { }

        public void PanelShown(uint documentSerialNumber, ShowPanelReason reason)
        { }
    }

    public class Root : ITreeGridStore<Node>, ITreeGridItem
    {
        List<Node> nodes;
        public Root()
        {
            nodes = new List<Node>();
            for (int i = 0; i < 10; i++)
            {
                nodes.Add(new NodeA(this));
                nodes.Add(new NodeA(this));
                nodes.Add(new NodeB(this));
                nodes.Add(new NodeB(this));
            }
        }
        public Node this[int index] => nodes[index];
        public bool Expanded { get; set; }
        public bool Expandable => false;
        public ITreeGridItem Parent { get; set; }

        public int Count => nodes.Count;
    }
    public class Node : ITreeGridItem
    {
        public Node(ITreeGridItem p) { Parent = p; }
        public bool Expanded { get; set; }
        public bool Expandable => false;
        public ITreeGridItem Parent { get; set; }
        public virtual Control CreateCell(CellEventArgs a) => throw new NotImplementedException();
    }
    public class NodeA : Node
    {
        public NodeA(ITreeGridItem p) : base(p) { }
        public override Control CreateCell(CellEventArgs a)
        {
            return new Label { Text = "A  A  A", BackgroundColor = Colors.Blue };
        }
    }
    public class NodeB : Node 
    {
        public NodeB(ITreeGridItem p) : base(p) { }
        public override Control CreateCell(CellEventArgs a)
        {
            return new Label { Text = "B  B  B", BackgroundColor = Colors.Yellow };
        }
    }

}
